import socket
import threading

# Глобальные переменные
server_variable = None
server_running = True

def handle_client(conn, addr):
    global server_variable
    try:
        data = conn.recv(1024).decode()
        if not data:
            return
        if data.startswith('SET'):
            # Обновление переменной
            new_value = data[len('SET:'): ]
            server_variable = new_value
            conn.send('OK'.encode())
        elif data == 'GET':
            # Отправка текущего значения
            if server_variable is None:
                server_variable = '0'  # Значение по умолчанию
            conn.send(('V' + str(server_variable)).encode())
        else:
            conn.send('Unknown command'.encode())
    finally:
        conn.close()

def start_server():
    global server_running
    host = '0.0.0.0'
    port = 11012
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
        s.bind((host, port))
        s.listen()
        print(f'Server started at {host}:{port}')
        while server_running:
            try:
                conn, addr = s.accept()
                threading.Thread(target=handle_client, args=(conn, addr), daemon=True).start()
            except:
                break
        print('Server stopped.')

def stop_server():
    global server_running
    server_running = False
    # Триггер для разрыва accept
    try:
        with socket.create_connection(('localhost', 12345), timeout=1):
            pass
    except:
        pass
start_server()


import socket
import os
def get_variable(ip, port):
    with socket.create_connection((ip, port)) as sock:
        sock.sendall('GET'.encode())
        data = sock.recv(1024).decode()
        if data.startswith('V'):
            return data[1:]
        return None

# Запрос IP сервера у пользователя
server_ip = input("Введите IP сервера: ")
server_port = 11012
encoding=input('ключ дешифрования: ')
a=get_variable(server_ip, server_port)
while True:
    b=get_variable(server_ip, server_port)
    if b != a:
        a=b
        c=''
        b=b.split(' ')
        for i in b[:-1]:
            c+=encoding[int(i)]
        print(c)


import socket
def send_variable(ip, port, value):
    with socket.create_connection((ip, port)) as sock:
        sock.sendall(('SET:' + str(value)).encode())
        response = sock.recv(1024).decode()
        print("Ответ сервера:", response)

# Запрос IP сервера у пользователя
server_ip = input("Введите IP сервера: ")
server_port = 11012
encoding=input('ключ шефрования: ')
while True:
    a = input()
    c = ''
    for x in a:
        for y in range(len(encoding)):
            if x == encoding[y]:
                c+=str(y)+' '
    send_variable(server_ip, server_port, c)


from setuptools import setup
setup(
    name='messandger_da',
    version='0.2',
    packages = ['server', 'history', 'sender'],
    install_requires=[],
    python_requires=">=3.11",
    author="DavidYdin",
    author_email="David.2280@yandex.ru"
)